package com.fs.sop.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.common.annotation.DataSource;
import com.fs.common.enums.DataSourceType;
import com.fs.sop.domain.QwSopTemp;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * sop模板Mapper接口
 *
 * @author fs
 * @date 2024-09-26
 */
@DataSource(DataSourceType.SOP)
public interface QwSopTempMapper extends BaseMapper<QwSopTemp> {
    /**
     * 查询sop模板
     *
     * @param id sop模板主键
     * @return sop模板
     */
    public QwSopTemp selectQwSopTempById(String id);

    /**
     * 查询sop模板列表
     *
     * @param qwSopTemp sop模板
     * @return sop模板集合
     */
    public List<QwSopTemp> selectQwSopTempList(QwSopTemp qwSopTemp);

    public List<QwSopTemp> selectQwSopTempListNew(QwSopTemp qwSopTemp);

    /**
     * 新增sop模板
     *
     * @param qwSopTemp sop模板
     * @return 结果
     */
    public int insertQwSopTemp(@Param("data")QwSopTemp qwSopTemp);

    /**
     * 修改sop模板
     *
     * @param qwSopTemp sop模板
     * @return 结果
     */
    public int updateQwSopTemp(@Param("data") QwSopTemp qwSopTemp);

    /**
     * 删除sop模板
     *
     * @param id sop模板主键
     * @return 结果
     */
    public int deleteQwSopTempById(String id);

    /**
     * 批量删除sop模板
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteQwSopTempByIds(String[] ids);

    public int updateQwSopTempByIds(@Param("ids") String[] ids);

    List<QwSopTemp> listTemp();

    List<QwSopTemp> selectListByIds(@Param("ids") List<String> ids);
}
